import { DeepPartial, EditorState, HorizontalGuideline, SidebarType, VerticalGuideline, BoxData, BoxSize, CursorPosition, Delta, FontData, LayerComponentProps, LayerId, PageSize, SerializedLayer, SerializedLayerTree, SerializedPage } from '../../types';
import { TextEditor } from '../text-editor/interfaces';
import { Direction, EdgeDirection } from '../../types/resize';
import { ImageContentProps } from '../../layers';
export declare const ActionMethods: (state: EditorState) => {
    setProp<T extends LayerComponentProps>(pageIndex: number, layerId: LayerId | LayerId[], props: DeepPartial<T>, customizer?: ((objVal: unknown, srcVal: unknown) => unknown) | undefined): void;
    moveSelectedLayers: (direction: EdgeDirection, value: number) => void;
    changePageSize: (size: PageSize) => void;
    setScale: (scale: number) => void;
    setGuideline: ({ vertical, horizontal, }: {
        vertical: VerticalGuideline[];
        horizontal: HorizontalGuideline[];
    }) => void;
    togglePageSettings: () => void;
    setSidebarTab: (tab?: string | null) => void;
    selectLayers(pageIndex: number, layerIds: LayerId | LayerId[], type?: 'replace' | 'add'): void;
    selectAllLayers: () => void;
    resetSelectLayer: () => void;
    hoverLayer: (pageIndex: number, layerId: LayerId | null) => void;
    setAlign(alignment: 'left' | 'right' | 'center' | 'top' | 'bottom' | 'middle'): void;
    setTextEditor: (pageIndex: number, layerId: LayerId, editor: TextEditor) => void;
    setData: (serializedPages: SerializedPage[]) => void;
    setPage: (pageIndex: number, serializedPage: SerializedPage) => void;
    setPageName(pageIndex: number, name: string): void;
    setPageNotes(pageIndex: number, notes: string): void;
    setActivePage(pageIndex: number): void;
    deleteLayer: (pageIndex: number, layerId: LayerId | LayerId[]) => void;
    openTextEditor(pageIndex: number, layerId: LayerId): void;
    setOpeningEditor(editor: TextEditor): void;
    closeTextEditor(): void;
    lockPage: (pageIndex: number) => void;
    unlockPage: (pageIndex: number) => void;
    deletePage: (pageIndex: number) => void;
    duplicatePage(pageIndex: number): void;
    addPage: (pageIndex?: number) => void;
    movePageUp: (pageIndex: number) => void;
    movePageDown: (pageIndex: number) => void;
    swapPagePosition: (from: number, to: number) => void;
    lock: (pageIndex: number, layerId: LayerId | LayerId[]) => void;
    unlock: (pageIndex: number, layerId: LayerId | LayerId[]) => void;
    ungroup(layerId: LayerId): string[];
    group(layerIds: LayerId[]): string;
    bringToFront: (pageIndex: number, layerId: LayerId | LayerId[], toIndex?: number) => void;
    bringForward: (pageIndex: number, layerId: LayerId | LayerId[]) => void;
    sendToBack: (pageIndex: number, layerId: LayerId | LayerId[], toIndex?: number) => void;
    sendBackward: (pageIndex: number, layerId: LayerId | LayerId[]) => void;
    setFontList(list: FontData[]): void;
    appendFontList(list: FontData[]): void;
    addLayer(serializedLayer: Pick<SerializedLayer, 'type' | 'props'>, parentId?: LayerId): void;
    addShapeLayer(serializedLayer: Pick<SerializedLayer, 'type' | 'props'>, parentId?: LayerId): void;
    addFrameLayer(serializedLayer: Pick<SerializedLayer, 'type' | 'props'>, parentId?: LayerId): void;
    addImageLayer({ thumb, url, position, }: {
        url: string;
        thumb: string;
        position?: Delta | undefined;
    }, boxSize: BoxSize, parentId?: LayerId): void;
    addLayerTree({ layers, rootId }: SerializedLayerTree): void;
    addLayerTrees(data: SerializedLayerTree[]): {
        id: string;
        data: import('../../types').LayerData<LayerComponentProps>;
    }[];
    showContextMenu: ({ clientX, clientY }: CursorPosition) => void;
    hideContextMenu: () => void;
    setSelectData: (status: boolean) => void;
    setResizeData: (status: boolean, layerIds?: LayerId[], direction?: Direction, rotate?: number, boxSize?: BoxSize, cursor?: CursorPosition) => void;
    setRotateData: (status: boolean, rotate?: number) => void;
    setDragData: (status: boolean, layerIds?: LayerId[]) => void;
    setControlBox: (data?: BoxData) => void;
    setSidebar: (sidebar?: SidebarType) => void;
    openImageEditor(pageIndex: number, layerId: LayerId, { boxSize, position, rotate, image, }: {
        position: Delta;
        rotate: number;
        boxSize: BoxSize;
        image?: {
            url: string;
            thumb?: string | undefined;
            position: Delta;
            rotate: number;
            boxSize: BoxSize;
            transparency?: number | undefined;
        } | null | undefined;
        video?: {
            url: string;
            position: Delta;
            rotate: number;
            boxSize: BoxSize;
        } | null | undefined;
    }): void;
    updateImageEditor(data: DeepPartial<{
        position: Delta;
        rotate: number;
        boxSize: BoxSize;
        image: {
            url: string;
            position: Delta;
            rotate: number;
            boxSize: BoxSize;
        };
        video?: {
            url: string;
            position: Delta;
            rotate: number;
            boxSize: BoxSize;
        } | null;
    }>): void;
    closeImageEditor(): void;
    fireDownloadCmd(cmdEnum: -1 | 0 | 1): void;
    goToGithubPage(): void;
};
